[![PyPI version](https://badge.fury.io/py/sos-javascript.svg)](https://badge.fury.io/py/sos-javascript)
[![Build Status](https://travis-ci.org/vatlab/sos-javascript.svg?branch=master)](https://travis-ci.org/vatlab/sos-javascript)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/3d1899839d444a599ef061d55de45cab)](https://www.codacy.com/app/BoPeng/sos-javascript?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=vatlab/sos-javascript&amp;utm_campaign=Badge_Grade)
[![Coverage Status](https://coveralls.io/repos/github/vatlab/sos-javascript/badge.svg)](https://coveralls.io/github/vatlab/sos-javascript)

# sos-javascript
SoS extension for JavaScript. Please refer to [SoS Homepage](http://vatlab.github.io/SoS/) for details.

